@@ -1,5 +1,5 @@
 function plotpos
-global aibopos trtimetags window plotops legpos;
+global aibopos trtimetags window plotops legpos bodypos;
 clf;
 grid on;
 hold on;
@@ -28,12 +28,15 @@ ylabel('left-right');
 xlabel('back-forward');
 zlabel('down-up');
 
+%add time ticks
 for leg=1:4
 bob=permute(legpos(leg,:,:),[3 2 1]);
 trtimetags(leg,:)=plot3(bob(1,1),bob(1,2),bob(1,3), [specs(leg) 'x'], ...
     bob(end,1),bob(end,2),bob(end,3), [specs(leg) 'x'], 'MarkerSize',32)';
 end
 
+%plot heading
+
 function buttons=getButton(leg)
      global logfile info jpl;
 leg=leg-1;
